@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# Copyright (C) 2000-2004 Peter Selinger.
+# Copyright (C) 2000-2009 Peter Selinger.
 # This file is part of ccrypt. It is free software and it is covered
 # by the GNU general public license. See the file COPYING for details.
 
@@ -10,33 +10,34 @@
 
 # Usage: largefile-check.sh [dir]
 
-if [ -z "$srcdir" ]; then
+if test -z "$srcdir"; then
     srcdir=.
 fi
 
-NAME=$0
-CCRYPT="../src/ccrypt -f -K testkey"
-DIR=${TEMPDIR:-/tmp}
+. "$srcdir"/common.sh
 
-if [ "$1" ]; then
-    DIR="$1"
+NAME="$0"
+CCRYPT="../src/ccrypt -f -K testkey"
+
+if test "$1"; then
+    TMPDIR="$1"
 fi
 
-DATA=`mktemp $DIR/largefile-check-XXXXXX`
+DATA=`mktemp "$TMPDIR/ccrypt-largefile-check-XXXXXX"`
 
 cleanup () {
     rm -rf "$DATA"
-    rm -rf "$DATA".cpt
+    rm -rf "$DATA.cpt"
 }
 
 trap cleanup EXIT
-trap cleanup SIGINT
+trap cleanup INT
 
 action () {
     "$@"
-    if [ $? -ne 0 ]; then
-	echo $NAME: test failed >& 2
-	echo Failed command: $LINE: "$@" >& 2
+    if test $? -ne 0; then
+	echo "$NAME: test failed" >& 2
+	echo "Failed command: $LINE: $@" >& 2
 	cleanup
 	exit 1
     fi
@@ -46,11 +47,11 @@ action () {
 alias action="LINE=\$LINENO; action"
 
 echo "Creating large file (>4GB)..."
-action dd if=/dev/zero of=$DATA bs=1024 count=4200000 >/dev/null
+action dd if=/dev/zero of="$DATA" bs=1024 count=4200000 >/dev/null
 
 echo "Encrypting file..."
 action $CCRYPT "$DATA"
 
-echo $NAME: test succeeded >&2
+echo "$NAME: test succeeded" >&2
 cleanup
 exit 0
