@@ -1,25 +1,30 @@
-/* Copyright (C) 2000-2004 Peter Selinger.
+/* Copyright (C) 2000-2009 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
 /* readkey.c: read secret key phrase from terminal */
-/* $Id: readkey.c,v 1.4 2003/08/25 18:06:20 selinger Exp $ */
+/* $Id: readkey.c 258 2009-08-26 17:46:10Z selinger $ */
 
 #include <termios.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <errno.h>
 
 #include "xalloc.h"
 
+#include "gettext.h"
+#define _(String) gettext (String)
+
 /* read key from /dev/tty */
-char *readkey(char *prompt, char *promptcont, char *myname) {
+char *readkey(const char *prompt, const char *promptcont, const char *myname) {
   char *line;
   FILE *fin;
   struct termios tio, saved_tio;
 
   fin = fopen("/dev/tty", "r");
   if (fin==NULL) {
-    fprintf(stderr, "%s: cannot open /dev/tty\n", myname);
+    fprintf(stderr, _("%s: cannot open /dev/tty: %s\n"), myname, strerror(errno));
     exit(2);
   }
 
