@@ -1,8 +1,8 @@
-/* Copyright (C) 2000-2004 Peter Selinger.
+/* Copyright (C) 2000-2009 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
-/* $Id: unixcrypt3.c,v 1.4 2003/03/30 00:38:29 selinger Exp $ */
+/* $Id: unixcrypt3.c 258 2009-08-26 17:46:10Z selinger $ */
 /* A drop-in replacement for crypt(3), where it is not available as a
    library function. Derived from GNU sources and specialized. */
 
@@ -490,7 +490,7 @@ shuffle_sb(k, saltbits)
 
 static void
 _ufc_setup_salt_r(s, __data)
-     __const char *s;
+     const char *s;
      struct crypt_data *__data;
 {
   ufc_long i, j, saltbits;
@@ -621,7 +621,7 @@ _ufc_dofinalperm_r(res, __data)
 static void
 _ufc_output_conversion_r(v1, v2, salt, __data)
      ufc_long v1, v2;
-     __const char *salt;
+     const char *salt;
      struct crypt_data *__data;
 {
   int i, s, shf;
