@@ -1,12 +1,12 @@
-/* Copyright (C) 2000-2004 Peter Selinger.
+/* Copyright (C) 2000-2009 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
-/* $Id: unixcrypt3.h,v 1.3 2003/03/30 00:38:29 selinger Exp $ */
+/* $Id: unixcrypt3.h 258 2009-08-26 17:46:10Z selinger $ */
 
 #ifndef __UNIXCRYPT3_H
 #define __UNIXCRYPT3_H
 
 char *crypt_replacement (const char *key, const char *salt);
 
-#endif /* __UNiXCRYPT3_H */
+#endif /* __UNIXCRYPT3_H */
