@@ -1,9 +1,9 @@
-/* Copyright (C) 2000-2004 Peter Selinger.
+/* Copyright (C) 2000-2009 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
 /* unixcryptlib.c: library to simulate old "unix crypt" program */
-/* $Id: unixcryptlib.h,v 1.2 2003/03/30 00:38:29 selinger Exp $ */
+/* $Id: unixcryptlib.h 258 2009-08-26 17:46:10Z selinger $ */
 
 /* WARNING: do not use this software for encryption! The encryption
    provided by this program has been broken and is not secure. Only
@@ -14,7 +14,7 @@
 
 #include "ccryptlib.h"
 
-int unixcrypt_init(ccrypt_stream_t *b, char *key);
+int unixcrypt_init(ccrypt_stream_t *b, const char *key);
 int unixcrypt(ccrypt_stream_t *b);
 int unixcrypt_end(ccrypt_stream_t *b);
 
