@@ -1,9 +1,9 @@
-/* Copyright (C) 2000-2004 Peter Selinger.
+/* Copyright (C) 2000-2009 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
 /* xalloc.h: safe dynamic allocation */
-/* $Id: xalloc.h,v 1.3 2003/03/30 00:38:29 selinger Exp $ */
+/* $Id: xalloc.h 258 2009-08-26 17:46:10Z selinger $ */
 
 #ifndef __XALLOC_H
 #define __XALLOC_H
@@ -11,12 +11,12 @@
 #include <stdio.h>
 
 /* safe malloc */
-void *xalloc(size_t size, char *myname);
+void *xalloc(size_t size, const char *myname);
 
 /* safe realloc */
-void *xrealloc(void *p, size_t size, char *myname);
+void *xrealloc(void *p, size_t size, const char *myname);
 
 /* read an allocated line from input stream */
-char *xreadline(FILE *fin, char *myname);
+char *xreadline(FILE *fin, const char *myname);
 
 #endif /* __XALLOC_H */
